@@ -106,6 +106,8 @@ module BloggerPost
       @boot = false
       define_modes
       define_faces
+      elvar.bloggerpost_browse_url_func = :browse_url
+      elvar.bloggerpost_preview_func = :browse_url
     end
 
     private
@@ -158,6 +160,14 @@ module BloggerPost
       @entry_list.find {|item| item.url == url }
     end
 
+    def bloggerpost_browse_url(url)
+      apply(elvar.bloggerpost_browse_url_func, url, [])
+    end
+
+    def bloggerpost_preview(url)
+      apply(elvar.bloggerpost_preview_func, url, [])
+    end
+
     # top
 
     def update_list
@@ -268,6 +278,14 @@ module BloggerPost
       bloggerpost_bloglist_update
     end
 
+    defun(:bloggerpost_bloglist_browse_url, :interactive => true) do
+      is_draft = get_text_property(point, :draft)
+      unless is_draft
+        blog = find_blog(get_text_property(point, :blog_name))
+        bloggerpost_browse_url(blog.url)
+      end
+    end
+
     def bloglist_mode_keymap
       {
         "\r" => :bloggerpost_bloglist_select_current,
@@ -275,7 +293,8 @@ module BloggerPost
         "q"  => :bloggerpost_bloglist_exit,
         "s"  => :bloggerpost_bloglist_force_update,
         "w"  => :bloggerpost_draft,
-        "G"  => :bloggerpost_global_search
+        "G"  => :bloggerpost_global_search,
+        "b"  => :bloggerpost_bloglist_browse_url
       }
     end
 
@@ -514,6 +533,11 @@ module BloggerPost
       bloggerpost_entrylist_update
     end
 
+    defun(:bloggerpost_entrylist_browse_url, :interactive => true) do
+      entry = find_entry(get_text_property(point, :url))
+      bloggerpost_browse_url(entry.url)
+    end
+
     def entrylist_mode_keymap
       {
         "\r"   => :bloggerpost_entrylist_read,
@@ -528,7 +552,8 @@ module BloggerPost
         "D"    => :bloggerpost_entrylist_delete,
         "S"    => :bloggerpost_entrylist_sort,
         "g"    => :bloggerpost_entrylist_search,
-        "G"    => :bloggerpost_global_search
+        "G"    => :bloggerpost_global_search,
+        "b"    => :bloggerpost_entrylist_browse_url
       }
     end
 
@@ -675,6 +700,7 @@ module BloggerPost
         message("Sending 'POST' request...")
         if entry.draft?
           request.new_post(entry)
+          update_list
         else
           request.edit_post(entry)
         end
@@ -725,6 +751,7 @@ module BloggerPost
       entry.body = $1
       entry.blog_name = blog_name if blog_name
       entry.trackback_list = trackback_list if trackback_list
+      entry.clear_cache
     end
 
     defun(:bloggerpost_draft_save, :interactive => true) do
@@ -745,6 +772,15 @@ module BloggerPost
       bloggerpost_draft_exit
     end
 
+    defun(:bloggerpost_draft_preview, :interactive => true) do
+      entry = find_entry(get_draft_url)
+      read_buffer_to_entry
+      File.open(@config.preview_file, 'w') do |file|
+        file.write(entry.to_html)
+      end
+      bloggerpost_preview(@config.preview_file)
+    end
+
     def bloggerpost_draft_header_end
       end_point = 0
       with(:save_restriction) do
@@ -771,6 +807,7 @@ module BloggerPost
         "\C-c\C-k" => :bloggerpost_draft_kill,
         "\C-x\C-s" => :bloggerpost_draft_save,
         "\C-c\C-z" => :bloggerpost_draft_save_and_exit,
+        "\C-c\C-p" => :bloggerpost_draft_preview,
         "\C-a"     => :bloggerpost_draft_beginning_of_line
       }
     end
